# mwdb-iocextract

Python 3 library useful for getting structured IOC data from mwdb configs. 

## Info

**Contact email**: msm@cert.pl

## Install

```bash
$ pip install mwdb-iocextract
```

## Example

TODO
